==> haskell-monad-journal-0.8.1-31-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-monad-journal.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: monad-journal
version: 0.8.1
id: monad-journal-0.8.1-5a6B6z68xHrEOgqX1UQirE
key: monad-journal-0.8.1-5a6B6z68xHrEOgqX1UQirE
license: BSD-3-Clause
maintainer: Dimitri Sabadie <dimitri.sabadie@gmail.com>
author: Dimitri Sabadie <dimitri.sabadie@gmail.com>
homepage: http://github.com/phaazon/monad-journal
synopsis: Pure logger typeclass and monad transformer
description:
    This package provides a typeclass for logging in
    pure code, or more generally, in any kind of
    context. You can do whatever you want with
    logs, especially get them, clear them or even
    sink them through '\''IO'\'' if you'\''re logging in
    @(MonadIO m) => m@.
category: Control
abi: 29bc9ad6787e4c43911afba76ba4b846
exposed: True
exposed-modules:
    Control.Monad.Journal Control.Monad.Journal.Class
    Control.Monad.Trans.Journal
import-dirs: /usr/lib/ghc-8.6.4/site-local/monad-journal-0.8.1
library-dirs: /usr/lib/ghc-8.6.4/site-local/monad-journal-0.8.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/monad-journal-0.8.1
hs-libraries: HSmonad-journal-0.8.1-5a6B6z68xHrEOgqX1UQirE
depends:
    base-4.12.0.0 monad-control-1.0.2.3-8d9BFLxdv0m5ZddAp98CYo
    mtl-2.2.2 transformers-0.5.6.2
    transformers-base-0.4.5.2-CiZEid5DnKxKMvWGI9SJsd
haddock-interfaces: /usr/share/doc/haskell-monad-journal/html/monad-journal.haddock
haddock-html: /usr/share/doc/haskell-monad-journal/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-monad-journal-0.8.1-38-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-monad-journal.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: monad-journal
version: 0.8.1
id: monad-journal-0.8.1-GAuYKFImVCYEp6HiRphY6Q
key: monad-journal-0.8.1-GAuYKFImVCYEp6HiRphY6Q
license: BSD-3-Clause
maintainer: Dimitri Sabadie <dimitri.sabadie@gmail.com>
author: Dimitri Sabadie <dimitri.sabadie@gmail.com>
homepage: http://github.com/phaazon/monad-journal
synopsis: Pure logger typeclass and monad transformer
description:
    This package provides a typeclass for logging in
    pure code, or more generally, in any kind of
    context. You can do whatever you want with
    logs, especially get them, clear them or even
    sink them through '\''IO'\'' if you'\''re logging in
    @(MonadIO m) => m@.
category: Control
abi: 7ae3cd02734de5a7aaa6be754e571857
exposed: True
exposed-modules:
    Control.Monad.Journal Control.Monad.Journal.Class
    Control.Monad.Trans.Journal
import-dirs: /usr/lib/ghc-8.6.5/site-local/monad-journal-0.8.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/monad-journal-0.8.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/monad-journal-0.8.1
hs-libraries: HSmonad-journal-0.8.1-GAuYKFImVCYEp6HiRphY6Q
depends:
    base-4.12.0.0 monad-control-1.0.2.3-DXP4ByOEjHJ5rVzR8ITkTD
    mtl-2.2.2 transformers-0.5.6.2
    transformers-base-0.4.5.2-KiogS5KFFp4IwxvJXTI1QL
haddock-interfaces: /usr/share/doc/haskell-monad-journal/html/monad-journal.haddock
haddock-html: /usr/share/doc/haskell-monad-journal/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
